@@ -5,15 +5,19 @@ designMatrices.mfr <-
   function( resp, formulaA = ~ item + item:step, facets = NULL,  
             constraint = c("cases", "items"), ndim = 1,
             Q=NULL, A=NULL, B=NULL , progress=FALSE ){
-    z0 <- Sys.time()
+			
+tamcat_active <- TRUE
+tamcat_active <- FALSE			
+z0 <- Sys.time()	
+
     ### Basic Information and Initializations
     constraint <- match.arg(constraint)
     ## restructure formulaA
     t1 <- attr( terms( formulaA ) , "term.labels" )
     t2 <- intersect( c("item" , "step" , "item:step") , t1 )
-    
-    
-    # cat(" ---  z20" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1     	
+   
+z0 <- tamcat( " ---  z20" , z0 , tamcat_active )    
+
     formulaA <- paste(  paste( c(t2 , setdiff(t1 , t2 ) ) , collapse= " + " ) )
     formulaA <- as.formula( paste( " ~ " , formulaA ) )	
     
@@ -46,8 +50,9 @@ designMatrices.mfr <-
         }
       }
     }
-    #cat(" ---  z50" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1     				
-    
+
+z0 <- tamcat( " ---  z50" , z0 , tamcat_active )    
+   
     #********************************	
     #    resp[ is.na(resp) ] <- 0
     maxKi <- apply( resp , 2 , max , na.rm=TRUE )
@@ -58,13 +63,15 @@ designMatrices.mfr <-
       colnames(resp) <- paste0( "item" , 1:nI )
     }
     
-    # cat(" ---  before .A.matrix" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1     						
+z0 <- tamcat( " ---  before .A.matrix" , z0 , tamcat_active )    
     
     # A Matrix
     if( is.null(A) ){
+#!!!! work on speeding this step!!	
       AX <- .A.matrix( resp, formulaA = formulaA, facets = facets, constraint = constraint ,
                        progress=progress)
-      
+z0 <- tamcat( " ---  after .A.matrix" , z0 , tamcat_active )    
+
       A <- AX$A; X <- AX$X; otherFacets <- AX$otherFacets
       xsi.constr <- AX$xsi.constr
       facet.design <- AX$facet.design
@@ -73,8 +80,9 @@ designMatrices.mfr <-
       X.noStep <- unique(X[,- grep("step", colnames(X)), drop = FALSE ])  
       rownames(X.noStep) <- gsub("-step([[:digit:]])*", "", rownames(X.noStep))      
     } 	
-# Revalprstr("X.noStep")
-# Revalpr("X.noStep")
+
+z0 <- tamcat( " ---  A matrix (is.null(A)" , z0 , tamcat_active )    
+
     # TK: 2014-03-12
     # Consider long vector response matrix
     if( "item" %in% colnames(facets) & "item" %in% t2 ) otherFacets <-  c("item", otherFacets)
@@ -85,10 +93,9 @@ designMatrices.mfr <-
     if (progress){ 
       cat( "        o Created A Matrix (" , paste(Sys.time()) , ")\n") ; flush.console();
     }
+   
+z0 <- tamcat( " ---  created A matrix" , z0 , tamcat_active )    
 
-# Revalpr("X.noStep.ind")
-    
-    # cat(" ---  created A matrix" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1     					
     # Q Matrix
     
     if( is.null(Q) ){
@@ -103,7 +110,8 @@ designMatrices.mfr <-
     # ndim
     ndim <- dim(Q)[2]
 
-    # cat(" ---  after Q" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1        
+z0 <- tamcat( " ---  after Q" , z0 , tamcat_active )    
+
     # B Matrix
     if( is.null(B) ){ 
       B.store.in <- NULL
@@ -118,27 +126,32 @@ designMatrices.mfr <-
 
     # gresp
     ind.resp.cols <- as.numeric(X.ind)
-    # cat(" ---  before gresp   " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1    
-    gresp <- resp[,ind.resp.cols]	
-    # cat(" ---  after gresp selection   " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1    	
-    #    gresp <- 1* ( gresp == t(array( X[, "step"], dim = dim(t(gresp)) )) )	
-        
+z0 <- tamcat( " ---  before gresp" , z0 , tamcat_active )    	
+    gresp <- resp[,ind.resp.cols]		
+z0 <- tamcat( " ---  after gresp selection   " , z0 , tamcat_active )    		
+
+#	res <- gresp_selection( as.matrix(resp) , ind.resp.cols-1 )
+# no much time gain with Rcpp function
+# cat(" ---  after gresp selection (Rcpp)  " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1    	
+ #    gresp <- 1* ( gresp == t(array( X[, "step"], dim = dim(t(gresp)) )) )	        
 #    gresp <- 1*(gresp==matrix( as.numeric(X[,"step"]) , nrow(gresp) , ncol(gresp) , byrow=TRUE ))
-    # cat(" ---  after gresp   " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1    
+
     # This step is time-consuming!!
 	#**** ARb 2014-05-30
 	gresp <- .Call("gresp_extend" , as.matrix(gresp) , as.numeric( X[,"step"] ) ,
 					PACKAGE="TAM")    
-    
-    
+z0 <- tamcat( " ---  after gresp   " , z0 , tamcat_active )      
+        
     ind.resp.cols <- as.numeric(X.noStep.ind)
     gresp.noStep <- resp[,ind.resp.cols]
-    # cat(" ---  gresp no step    " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1
+z0 <- tamcat( " ---  gresp ind.resp.cols   " , z0 , tamcat_active )      	
+
     if( length(otherFacets) > 0 ){
       rnFacets <- rownames( rownames.design2( as.matrix(facets[,otherFacets]) ))
       rnX <-      rownames( rownames.design2( as.matrix(X[,otherFacets]) ))
       rnX.noStep <-      rownames( rownames.design2( as.matrix(X.noStep[,otherFacets]) ))   
-      # cat("rownames.design2  X" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1		  
+z0 <- tamcat( " ---  rownames.design2   " , z0 , tamcat_active )  
+
       #*** ARb 2013-03-26:
       #*** Set all entries in gresp and gresp.noStep to missing
       #*** if they are not observed.
@@ -148,16 +161,31 @@ designMatrices.mfr <-
 #      gresp.noStep[ outer(rnFacets, rnX.noStep, "!=") ] <- NA
 	  gresp <- .Call("gresp_na_facets" ,  as.matrix(gresp) , rnFacets , rnX ,
 				PACKAGE="TAM")
+z0 <- tamcat( " ---  gresp na facets gresp   " , z0 , tamcat_active )  				
 	  gresp.noStep <- .Call("gresp_na_facets", as.matrix(gresp.noStep ) , rnFacets , rnX.noStep ,
 				PACKAGE="TAM"	  )	
-      # cat("gresp NA " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1	
+z0 <- tamcat( " ---  gresp na facets gresp.noStep   " , z0 , tamcat_active )  				
       
     }
-    #cat(" ---  after other facets" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1    	
+#  cat(" ---  after other facets" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1    	
     colnames(gresp) <- rownames(X)
-    X$empty <- 1* (colSums( gresp, na.rm=TRUE ) == 0)
-    colnames(gresp.noStep) <- rownames(X.noStep)
-    X.noStep$empty <- 1* (colSums( gresp.noStep, na.rm=TRUE ) == 0)
+
+#    X$empty <- 1* (colSums( gresp, na.rm=TRUE ) == 0)
+# cat(" ---  col sums (gresp) in X " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1 	
+# X$empty <- colsums_gresp( gresp )
+# cat(" ---  col sums (gresp) in X (Rcpp)" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1 		
+# X$empty <- colsums_gresp2( gresp )
+# data communication with Rcpp does need no computation time
+
+	X$empty <- .Call( "colsums_gresp" , gresp , PACKAGE="TAM")
+z0 <- tamcat( " ---  col sums (gresp) in X (Rcpp)" , z0 , tamcat_active )  				 
+
+
+    colnames(gresp.noStep) <- rownames(X.noStep)	
+#    X.noStep$empty <- 1* (colSums( gresp.noStep, na.rm=TRUE ) == 0)
+	X.noStep$empty <- .Call( "colsums_gresp" , gresp.noStep , PACKAGE="TAM")
+z0 <- tamcat( " ---  col sums (gresp noStep) in X (Rcpp)" , z0 , tamcat_active )  				 
+
     ### output
     ind <- X[,"empty"] == 1
     nStep <- maxK+1
@@ -171,25 +199,26 @@ designMatrices.mfr <-
                      , c(2,1,3) 
       ) )
     }
+	
+#**************************
     # generate B
     .generateB.3d <- function(x){  
       x2 <- array( 0 , c(nStep , nGenit/nStep , ncol(x) ) )
       dimnames(x2) <- list( paste("_step",0:maxK, sep= ""), 
                             unique(gsub("(^|-)+step([[:digit:]])*", "", rownames(x))),
-                            colnames(x) )
-      for (dd in seq(1 , ncol(x) ) ){
-        for (ss in 0:(nStep-1)){
-          str.ss <- paste0("step",ss )
-          iss <- grep(  paste0(str.ss,"+(-|$)") , rownames(x))# , fixed=TRUE )
-          str.ss2 <- gsub( paste0("(^|-)+",str.ss) , "" , rownames(x)[iss] )
-          x2[ss+1,str.ss2,dd] <- as.vector(x[ iss , dd])
-          #			x2[ ss,,dd] <- matrix( x[,dd] , nrow=nStep , ncol= dim(x2)[2] , byrow=TRUE)
-        }
-      }
+                            colnames(x) )							
+	for (ss in 0:(nStep-1)){
+			  str.ss <- paste0("step",ss )
+			  iss <- grep(  paste0(str.ss,"+(-|$)") , rownames(x) )# , fixed=TRUE )
+			  str.ss2 <- gsub( paste0("(^|-)+",str.ss) , "" , rownames(x)[iss] )
+			  x2[ss+1,str.ss2,] <- x[ iss , ]
+			}
       x2 <- aperm( x2 , c(2,1,3) )
       return(x2)
     }    
-    # cat(" ---  before item rename" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1    
+#**************************	
+	
+# cat(" ---  before item rename" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1    
     #***
     # debugging ind manually
     ind <- FALSE * ind
@@ -201,88 +230,103 @@ designMatrices.mfr <-
     } else {
       itemren <- data.frame( "item" =  colnames(resp) , "itemren" = paste0( "item" , 1:nI ) )
     }
-    # cat(".....\nbefore rename A" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1	
-    # print("g100")	
+# cat(" --- .....before rename A" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1	
     A <- .rename.items( matr=A , itemren )
+z0 <- tamcat( " --- .rename.items (A)" , z0 , tamcat_active )  				 
+
+
     # print( dimnames(A) )
     # print(facet.list)
     dimnames(A)[[1]] <- .rename.items2aa( vec=dimnames(A)[[1]] ,
                                           facet.list=facet.list , I=I )
-    
-    # cat(".rename.items (A)" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1		
+z0 <- tamcat( " --- .rename.items2aa (A)" , z0 , tamcat_active )  				     
     xsi.table <- xsi.constr$xsi.table
-    #	A <- .rename.items3( matr=A , facet.list , I )	
-    #cat(".rename.items3 (A)" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1			
     A <- .rename.items3a( matr=A , facet.list , I , cols=TRUE , xsi.table )	
-    #cat(".rename.items3a (A)" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1			
-    B <- .rename.items( matr=B , itemren )	
-    # cat(".rename.items (B)" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1			
-    dimnames(B)[[1]] <- dimnames(A)[[1]]	
-    #	B <- .rename.items3( matr=B , facet.list )	
-    gresp <- t( .rename.items( matr=t(gresp) , itemren , cols=FALSE)	)
-    # cat(".rename.items (gresp)" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1				
-    #	gresp <- t( .rename.items3( matr=t(gresp) , facet.list , cols=FALSE)	)	
+z0 <- tamcat( " --- .rename.items3a (A)" , z0 , tamcat_active )
+
+#    B <- .rename.items( matr=B , itemren )		
+# z0 <- tamcat( " --- .rename.items (B)" , z0 , tamcat_active )  				     	
+  
+	dimnames(B)[[1]] <- dimnames(A)[[1]]		
+z0 <- tamcat( " ---  dimnames(B)" , z0 , tamcat_active )  				     			
+    #	B <- .rename.items3( matr=B , facet.list )		
+#    gresp <- t( .rename.items( matr=t(gresp) , itemren , cols=FALSE) )
+# z0 <- tamcat( " --- .rename.items (gresp)" , z0 , tamcat_active )  				     	 	
+	dimnames(gresp)[[2]] <- dimnames(A)[[1]]
+z0 <- tamcat( " ---  colnames(gresp) <- dimnames(A)" , z0 , tamcat_active )  				     	 
+
+#Revalpr("sum(dimnames(A)[[1]] != colnames(gresp))")
+
+ 
+    # gresp <- t( .rename.items3( matr=t(gresp) , facet.list , cols=FALSE)	)	
     dimnames(gresp)[[2]] <- dimnames(A)[[1]]	
     gresp.noStep <- t( .rename.items( matr=t(gresp.noStep) , itemren , cols=FALSE)	)	
-    # cat("h2" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1					
+z0 <- tamcat( " --- .rename.items (gresp.noStep)" , z0 , tamcat_active )
+
+  				     	 
     #	gresp.noStep <- t( .rename.items3( matr=t(gresp.noStep) , facet.list , I , cols=FALSE)	)	
     gresp.noStep <- t( .rename.items3a( matr=t(gresp.noStep) , facet.list , I , cols=FALSE ,
                                         xsi.table )	)		
-    #cat(".rename.items (gresp.noStep)" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1					
+z0 <- tamcat( " --- .rename.items (gresp.noStep) facet list" , z0 , tamcat_active ) 
+
+
     Q <- .rename.items( matr=Q , itemren , cols=FALSE)
     dimnames(Q)[[1]] <- dimnames(A)[[1]]
-    # cat(".rename.items (Q)" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1						
+z0 <- tamcat( " --- .rename.items (Q)" , z0 , tamcat_active ) 					
     # 	Q <- .rename.items3( matr=Q , facet.list , cols=FALSE)
     X <- .rename.items( matr=X , itemren , cols=FALSE)
     dimnames(X)[[1]] <- dimnames(A)[[1]]
     #	X <- .rename.items3( matr=X , facet.list , cols=FALSE)	
-    # cat(".rename.items (Q,X)" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1					
+z0 <- tamcat( " --- .rename.items (Q,X)" , z0 , tamcat_active )	
     X.noStep <- .rename.items( matr=X.noStep , itemren , cols=FALSE)
+z0 <- tamcat( " --- .rename.items (X.noStep)" , z0 , tamcat_active )	
     #	X.noStep <- .rename.items3( matr=X.noStep , facet.list , cols=FALSE)	
     #***
     G1 <- xsi.constr$xsi.table 	
     G1$parameter <- .rename.items2( paste( G1$parameter) , itemren) 	
-    # cat(".rename.items2 (G1$parameter)  " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1					
+z0 <- tamcat( " --- .rename.items2 (G1$parameter)" , z0 , tamcat_active )	
     #	G1$parameter <- .rename.items2a( paste( G1$parameter) , facet.list , I) 	
-    #cat(".rename.items2a (G1$parameter)  " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1					
-    G1$parameter <- .rename.items2b( paste( G1$parameter) , facet.list , I , xsi.table ) 	
+# cat(" --- .rename.items2a (G1$parameter)  " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1	
+     G1$parameter <- .rename.items2b( paste( G1$parameter) , facet.list , I , xsi.table ) 	
     xsi.constr$xsi.table <- G1	
-    # cat(".rename.items2b (G1$parameter)  " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1	
+z0 <- tamcat( " --- .rename.items2b (G1$parameter)" , z0 , tamcat_active )	
     #***
     G1 <- xsi.constr$xsi.constraints
     rownames(G1) <- .rename.items2( rownames(G1) , itemren) 	
     colnames(G1) <- .rename.items2( colnames(G1) , itemren) 
-    # cat(".rename.items2 (colnames(G1))  " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1					
+z0 <- tamcat( " --- .rename.items2 (colnames(G1))" , z0 , tamcat_active )	
     colnames(G1) <- .rename.items2b( colnames(G1) , facet.list , I , xsi.table , sel1=1) 
     rownames(G1) <- .rename.items2b( rownames(G1) , facet.list , I , xsi.table , sel1=2) 		
-    #cat(".rename.items2a (colnames(G1))  " ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1					
+z0 <- tamcat( " --- .rename.items2b (dimnames(G1))" , z0 , tamcat_active )	
     G1 -> xsi.constr$xsi.constraints
-    # cat("rename items" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1
+ #cat(" --- rename items" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1
     
     if (progress){ 
       cat( "        o Relabeled Variable Names (" , paste(Sys.time()) , ")\n") ; flush.console();
-    }
-    
-    # cat(" ---  after all item renames" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1    			
-    
+    }   
+z0 <- tamcat( " --- after all renames" , z0 , tamcat_active )	
     # A
     A.flat.0 <- A.flat <- A; A.flat.0[ind,] <- 0
     A.3d <- .generateB.3d( A.flat )
     A.flat <- A.flat[!ind,]
     A.3d.0 <- .generateB.3d( A.flat.0 )
+z0 <- tamcat( " --- A generate 3d" , z0 , tamcat_active )	
+ 
     # B                  
     B.flat.0 <- B.flat <- B; B.flat.0[ind,] <- 0
     B.3d <- .generateB.3d( B.flat )
     B.flat <- B.flat[!ind,]
     B.3d.0 <- .generateB.3d( B.flat.0 )
     if(!is.null(B.store.in)) B.3d.0[] <- B.store.in
+z0 <- tamcat( " --- B generate 3d" , z0 , tamcat_active )	
     
     # Q                  
     Q.flat.0 <- Q.flat <- Q; Q.flat.0[ind,] <- 0
     Q.3d <- .generateB.3d( Q.flat )
     Q.flat <- Q.flat[!ind,]
     Q.3d.0 <- .generateB.3d( Q.flat.0 )     
-    # cat(" ---  output mfr" ) ; z1 <- Sys.time() ; print(z1-z0) ; z0 <- z1    			
+z0 <- tamcat( " --- Q generate 3d" , z0 , tamcat_active )	
+
     # out
     out <- list( "gresp" = list("gresp"=gresp, "gresp.noStep"=gresp.noStep), 
                  "A" = list("A.flat"=A.flat, "A.flat.0"=A.flat.0, 
