@@ -10,11 +10,17 @@
        for (cc in 1:maxK){
 			B[ , cc,dd] <- E[,cc,dd,] %*% gammaslope
 						}
-					}
+					}			
 		return(B)
 			}
 #############################################################
-
+# faster function for computation of item loadings
+.mml.3pl.computeB.v2 <- function( Edes , gammaslope , E ){
+	B <- .Call("mml_3pl_compute_B_rcpp" ,
+			Edes , gammaslope , dim(E) , PACKAGE="TAM")$B
+	B <- array( B , dim(E)[1:3] )
+	return(B)
+		}
 
 
 ###########################################################################
